==> eslint-plugin-jsx-a11y-0.4.3.tgz: package/lib/rules/label-uses-for.js <==
/**
 * @fileoverview Enforce label tags have htmlFor attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorMessage = 'Form controls using a label to identify them must be ' + 'programmatically associated with the control using htmlFor';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['label'].concat(context.options[0]);
      var nodeType = (0, _getNodeType2.default)(node);

      // Only check 'label' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var hasHtmlForAttr = (0, _hasAttribute2.default)(node.attributes, 'htmlFor');

      if (hasHtmlForAttr === false) {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{
  "oneOf": [{ "type": "string" }, {
    "type": "array",
    "items": {
      "type": "string"
    },
    "minItems": 1,
    "uniqueItems": true
  }]
}];

==> eslint-plugin-jsx-a11y-0.6.1.tgz: package/lib/rules/label-uses-for.js <==
/**
 * @fileoverview Enforce label tags have htmlFor attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorMessage = 'Form controls using a label to identify them must be ' + 'programmatically associated with the control using htmlFor';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['label'].concat(context.options[0]);
      var nodeType = (0, _getNodeType2.default)(node);

      // Only check 'label' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var htmlForAttr = (0, _hasAttribute2.default)(node.attributes, 'htmlFor');
      var htmlForValue = (0, _getAttributeValue2.default)(htmlForAttr);
      var isInvalid = htmlForAttr === false || htmlForValue === null || htmlForValue === undefined;

      if (isInvalid) {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{
  "oneOf": [{ "type": "string" }, {
    "type": "array",
    "items": {
      "type": "string"
    },
    "minItems": 1,
    "uniqueItems": true
  }]
}];
